==> escudo-0.4.tbz2: escudo-0.4/chrome/escudo/content/escudo/payees/payees.js <==
/**
 *  This file is part of Escudo.
 *
 *  Escudo is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Escudo is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with Escudo.  If not, see <http://www.gnu.org/licenses/>.
 */


with (EscudoLib) {
  top.Escudo.Payees =  {
    s_pattern: "SELECT payee, count FROM view_payees WHERE payee LIKE :payee",
    s_payee: "SELECT id FROM payee WHERE payee=:payee_id",
    i_payee: "INSERT INTO payee(\"payee\") VALUES (:payee)",
    
    /*---------------------------------------
      Initialize / Shutdown
     --------------------------------------*/
    init: function() {
      addObserver("refresh", this.Observer);
      addObserver("invalid", this.Observer);
    },

    /*---------------------------------------
      Observer
     --------------------------------------*/
    Observer : {
      observe: function(subject, topic, data) {
        let tree = document.getElementById("tree-payees");
        let param = document.getElementById("param-payeesAccount");

        if (topic == "invalid") { param.textContent = data; }
        tree.builder.rebuild();
      }
    },

    /*---------------------------------------
      Helper function
     --------------------------------------*/
    getPayeesMatchingPattern: function(pattern) {
      let statement = getStatement(this.s_pattern);
      statement.params.payee = "%" + pattern + "%";

      var values = [];
      try {
        while (statement.executeStep()) {
          values.push({
            payee: statement.getString(0),
            count: statement.getInt32(1)
          });
        }
      } finally {
        statement.reset();
      }
      return values;
    },

    getPayeeId: function(payee) {
      let statement = getStatement(this.s_payee);
      statement.params.payee_id = payee;

      var id = undefined;
      try {
        while (statement.executeStep()) {
          id = statement.getInt32(0);
        }
      } finally {
        statement.reset();
      }
      return id;
    },

    getOrCreatePayee: function(payee) {
      dump("Check payee: " + payee);
      var id = this.getPayeeId(payee);
      if (id == undefined) { id = this.insert(payee); }
      return id;
    },

    insert: function(payee) {
      let statement = getStatement(this.i_payee);
      statement.params.payee = payee;
      
      try {
        statement.execute();
      } finally {
        statement.reset();
      }

      return lastInsertRowID();
    }
  }
  top.Escudo.Payees.init();
}

==> escudo-0.4.1.tbz2: escudo-0.4.1/chrome/escudo/content/escudo/payees/payees.js <==
/**
 *  This file is part of Escudo.
 *
 *  Escudo is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Escudo is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with Escudo.  If not, see <http://www.gnu.org/licenses/>.
 */


with (EscudoLib) {
  top.Escudo.Payees =  {
    s_pattern: "SELECT payee, count FROM view_payees WHERE payee LIKE :payee",
    s_payee: "SELECT id FROM payee WHERE payee=:payee_id",
    i_payee: "INSERT INTO payee(\"payee\") VALUES (:payee)",
    
    /*---------------------------------------
      Initialize / Shutdown
     --------------------------------------*/
    init: function() {
      addObserver("refresh", this.Observer);
      addObserver("invalid", this.Observer);
    },

    /*---------------------------------------
      Observer
     --------------------------------------*/
    Observer : {
      observe: function(subject, topic, data) {
        let tree = document.getElementById("tree-payees");
        let param = document.getElementById("param-payeesAccount");

        if (topic == "invalid") { param.textContent = data; }
        tree.builder.rebuild();
      }
    },

    /*---------------------------------------
      Helper function
     --------------------------------------*/
    getPayeesMatchingPattern: function(pattern) {
      let statement = getStatement(this.s_pattern);
      statement.params.payee = "%" + pattern + "%";

      var values = [];
      try {
        while (statement.step()) {
          values.push(statement.row.payee);
        }
      } finally {
        statement.reset();
      }
      return values;
    },

    getPayeeId: function(payee) {
      let statement = getStatement(this.s_payee);
      statement.params.payee_id = payee;

      var id = undefined;
      try {
        while (statement.step()) {
          id = statement.row.id;
        }
      } finally {
        statement.reset();
      }
      return id;
    },

    getOrCreatePayee: function(payee) {
      var id = this.getPayeeId(payee);
      if (id == undefined) { id = this.insert(payee); }
      return id;
    },

    insert: function(payee) {
      let statement = getStatement(this.i_payee);

      statement.params.payee = payee;
      statement.execute();

      return lastInsertRowID();
    }
  }
  top.Escudo.Payees.init();
}
